Coverage for arrakis_server/__init__.py: 40.0%

1# Copyright (c) 2022, California Institute of Technology and contributors

2#

3# You should have received a copy of the licensing terms for this

4# software included in the file "LICENSE" located in the top-level

5# directory of this package. If you did not, you can view a copy at

6# https://git.ligo.org/ngdd/arrakis-server/-/raw/main/LICENSE

7

8 try:

9 from ._version import version as __version__

10 except ModuleNotFoundError:

11 import setuptools_scm

12

13 __version__ = setuptools_scm.get_version(fallback_version="?.?.?")